# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
#
# The Original Code is the Bugzilla HTTP REST API proxy.
#
# The Initial Developer of the Original Code is
# the Mozilla Foundation.
# Portions created by the Initial Developer are Copyright (C) 2009
# the Initial Developer. All Rights Reserved.
#
# Contributor(s):
#   The Original Software was written to the Glory of God by 
#   Gervase Markham <written.to.the.glory.of.God@gerv.net>.
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****

package Bugzilla::API::Model::Configuration;

use strict;
use warnings;
use parent 'Catalyst::Model';

use Bugzilla::API::Model::Utils;
use Bugzilla::API::Request;
use JSON;
use Data::Walk;
  
sub get {
  my ($self, $c, $query) = @_;

  my $result;

  my $noflags = defined($query->{'flags'}) && $query->{'flags'} eq "0";

  # Bit of a hack to store it here, but it's persistent...
  $c->config->{'config_withflags'} ||= {};
  $c->config->{'config_noflags'} ||= {};
    
  my $cache = $noflags ? $c->config->{'config_noflags'} : 
                         $c->config->{'config_withflags'};
  
  if ($query->{'cached_ok'} && $cache->{'data'})  
  {
    # Fulfil request from cache
    $result = $cache->{'data'};
    $result->{'last_updated'} = $cache->{'last_updated'};
  }
  else {
    my $url = new URI($c->config->{'bugzilla_url'} . 'config.cgi');
    $url->query_param('ctype' => "json");

    if ($noflags) {
      $url->query_param('flags' => "0");
    }

    my $res = make_request($c, "GET", $url);
    
    if ($res->is_success && ${$res->content_ref} =~ /^{/) {
      my $data = $res->decoded_content({ charset => 'utf-8' });
      $result = from_json($data, {utf8 => 1});

      # Fill cache
      $cache->{'last_updated'} = time();
      $cache->{'data'} = $result;
    }
    else {
      $result = http_result2error($res);
    }  
  }
  
  return($result);
}

1;
